@@ -11,14 +11,10 @@ from __future__ import print_function
 import linecache
 import re
 import sys
-import tempfile
 import weakref
 import zlib
 from abc import ABCMeta
 from abc import abstractmethod
-from collections import Iterable
-from collections import Sized
-from functools import wraps
 from warnings import warn
 
 from six import reraise
@@ -28,8 +24,10 @@ __all__ = "InvalidQuery", "to_string", "to_func"
 
 NoneType = type(None)
 
+
 class InvalidQuery(Exception):
-    pass # pragma: no cover
+    pass  # pragma: no cover
+
 
 def validated_method(validator_name, func):
     def validated_method_wrapper(self, value, *args, **kwargs):
@@ -40,6 +38,7 @@ def validated_method(validator_name, func):
         return func(self, value, *args, **kwargs)
     return validated_method_wrapper
 
+
 def validator_metaclass(base=type):
     return type(
         base.__name__ + "WithValidatorMeta",
@@ -52,6 +51,7 @@ def validator_metaclass(base=type):
         })}
     )
 
+
 def require(*types):
     def require_(value, *args, **kwargs):
         if not isinstance(value, types):
@@ -75,6 +75,7 @@ Skip = object()
 Stripped = object()
 Missing = object()
 
+
 class BaseVisitor(with_metaclass(validator_metaclass(base=ABCMeta))):
     validate_gt = validate_gte = validate_lt = validate_lte = validate_ne = validate_eq = staticmethod(require_value)
     validate_query = staticmethod(require(dict))
@@ -95,7 +96,7 @@ class BaseVisitor(with_metaclass(validator_metaclass(base=ABCMeta))):
         if Stripped in (options, regex):
             return Stripped
 
-        extra_keys = set(context) - {'$options', '$regex'}
+        extra_keys = set(i for i in context if not i.startswith('$'))
         if extra_keys:
             raise InvalidQuery('Invalid query part %r. You can only have `$options` with `$regex`.' % ', '.join(
                 repr(k) for k in extra_keys
@@ -127,11 +128,11 @@ class BaseVisitor(with_metaclass(validator_metaclass(base=ABCMeta))):
 
     @abstractmethod
     def visit_eq(self, value, field_name, context):
-        pass # pragma: no cover
+        pass  # pragma: no cover
 
     @abstractmethod
     def render_and(self, parts):
-        pass # pragma: no cover
+        pass  # pragma: no cover
 
     def visit(self, query):
         return self.visit_query(query)
@@ -159,6 +160,7 @@ class BaseVisitor(with_metaclass(validator_metaclass(base=ABCMeta))):
             else:
                 yield self.visit_eq(value, name, query)
 
+
 class ExprVisitor(BaseVisitor):
     def __init__(self, closure, object_name):
         self.closure = closure
@@ -210,11 +212,11 @@ class ExprVisitor(BaseVisitor):
             regex, options = value
 
             if self.closure is None:
-                return "re.match(%r, %s[%r], %r)" % (regex, self.object_name, field_name, options)
+                return "re.search(%r, %s[%r], %r)" % (regex, self.object_name, field_name, options)
             else:
                 var_name = "var%s" % len(self.closure)
                 self.closure[var_name] = "re.compile(%r, %r)" % (regex, options)
-                return '%s.match(%s[%r])' % (var_name, self.object_name, field_name)
+                return '%s.search(%s[%r])' % (var_name, self.object_name, field_name)
     visit_options = visit_regex
 
     def visit_size(self, value, field_name, context):
@@ -237,10 +239,12 @@ class ExprVisitor(BaseVisitor):
             field_name, '' if value else 'not ', self.object_name,
         )
 
+
 def to_string(query, closure=None, object_name='row'):
     visitor = ExprVisitor(closure, object_name)
     return visitor.visit(query)
 
+
 def to_func(query, use_arguments=True):
     closure = {} if use_arguments else None
     as_string = to_string(query, closure, object_name='item')
